@@ -12,15 +12,16 @@
  * END HEADER
  */
 
-import Vue from 'vue'
-import Error from './Error.vue'
-import windowRegister from '../common/modules/window-register'
+import { createApp } from 'vue'
+import { createPinia } from 'pinia'
+import App from './App.vue'
+import windowRegister from '@common/modules/window-register'
 
 // The first thing we have to do is run the window controller
 windowRegister()
-
-// Create the Vue app because we need to reference it in our toolbar controls
-const app = new Vue(Error)
-
-// In the end: mount the app onto the DOM
-app.$mount('#app')
+  .then(() => {
+    const pinia = createPinia()
+    const app = createApp(App).use(pinia)
+    app.mount('#app')
+  })
+  .catch(e => console.error(e))
